@@ -1,5 +1,5 @@
 """
-Copyright 2022 Ilia Moiseev
+Copyright 2022-2023 Ilia Moiseev
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-from typing import Callable, Any, List, Dict
+from typing import Callable, Any
 from . import Dataset, Modifier, T
 
 
@@ -23,7 +23,7 @@ class ApplyModifier(Modifier):
     Modifier that maps a function to given dataset's items in a lazy way.
     """
     def __init__(self, dataset: Dataset[T], func: Callable[[T], Any],
-                 *args: List[Any], **kwargs: Dict[Any, Any]) -> None:
+                 *args: Any, **kwargs: Any) -> None:
         """
         Parameters
         ----------
