@@ -1,5 +1,5 @@
 """
-Copyright 2022 Ilia Moiseev
+Copyright 2022-2023 Ilia Moiseev
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -15,14 +15,14 @@ limitations under the License.
 """
 
 import os
-from typing import Any, Union, Literal, Dict, List
+from typing import Union, Literal
 
 from hashlib import md5
 from deepdiff import DeepDiff
 
 from . import Validator, DataValidationException
 from ..data import SizedDataset, T
-from ..base import MetaHandler, supported_meta_formats, Meta
+from ..base import MetaHandler, supported_meta_formats, PipeMeta, MetaFromFile
 
 
 class MetaValidator(Validator):
@@ -70,7 +70,7 @@ class MetaValidator(Validator):
     """
     def __init__(self, dataset: SizedDataset[T],
                  root: Union[str, None] = None,
-                 meta_fmt: Literal['.json', '.yml'] = '.json') -> None:
+                 meta_fmt: Literal['.json', '.yml', '.yaml'] = '.json') -> None:
         """
         Parameters
         ----------
@@ -106,14 +106,14 @@ class MetaValidator(Validator):
         else:
             self._save(meta, name)
 
-    def _save(self, meta: Meta, name: str) -> None:
+    def _save(self, meta: PipeMeta, name: str) -> None:
         self._mh.write(name, meta)
         print(f'Saved as {name}!')
 
-    def _load(self, name: str) -> Meta:
+    def _load(self, name: str) -> MetaFromFile:
         return self._mh.read(name)
 
-    def _check(self, query_meta) -> None:
+    def _check(self, query_meta: PipeMeta) -> None:
         diff = DeepDiff(self.base_meta, query_meta, verbose_level=2)
         if len(diff):
             print(diff.pretty())
