@@ -1,5 +1,5 @@
 """
-Copyright 2022 Ilia Moiseev
+Copyright 2022-2023 Ilia Moiseev
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -15,10 +15,10 @@ limitations under the License.
 """
 
 import warnings
-from typing import List, Dict, Any, Union
+from typing import Any, Union
 import pendulum
 
-from ..base import Traceable, Meta
+from ..base import Traceable, PipeMeta
 
 
 class Model(Traceable):
@@ -27,13 +27,13 @@ class Model(Traceable):
     Used to provide unified interface to any model, store metadata including metrics.
     """
     def __init__(self, *args: Any,
-                 meta_prefix: Union[Meta, str, None] = None, **kwargs: Any) -> None:
+                 meta_prefix: Union[PipeMeta, str, None] = None, **kwargs: Any) -> None:
         """
         Should be called in any successor - initializes default meta needed.
         Arguments passed in it should be related to model's hyperparameters, architecture.
         All additional arguments should have defaults - to be able to create model and then load.
         Successors may pass all of their parameters to superclass for it to be able to
-        log them in meta. Everything that is worth to document about model and data 
+        log them in meta. Everything that is worth to document about model and data
         it was trained on can be either in params or meta_prefix.
         """
         # Model accepts meta_prefix explicitly to not to record it in 'params'
@@ -75,7 +75,7 @@ class Model(Traceable):
         """
         raise NotImplementedError()
 
-    def get_meta(self) -> Meta:
+    def get_meta(self) -> PipeMeta:
         # Successors may not call super().__init__
         # they may not have these default fields
 
@@ -121,6 +121,6 @@ class ModelModifier(Model):
         self._model = model
         super().__init__(*args, **kwargs)
 
-    def get_meta(self) -> Meta:
+    def get_meta(self) -> PipeMeta:
         prev_meta = self._model.get_meta()
         return super().get_meta() + prev_meta
