@@ -1,5 +1,5 @@
 """
-Copyright 2022 Ilia Moiseev
+Copyright 2022-2023 Ilia Moiseev
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -21,7 +21,7 @@ import pendulum
 import glob
 from hashlib import md5
 
-from ..base import Traceable, MetaHandler, supported_meta_formats, Meta
+from ..base import Traceable, MetaHandler, supported_meta_formats, PipeMeta
 from .model import Model
 
 
@@ -32,7 +32,7 @@ class ModelLine(Traceable):
     but different epochs or using different data.
     """
     def __init__(self, folder: str, model_cls: Type = Model,
-                 meta_fmt: Literal['.json', '.yml'] ='.json', **kwargs: Any) -> None:
+                 meta_fmt: Literal['.json', '.yml', '.yaml'] = '.json', **kwargs: Any) -> None:
         """
         All models in line should be instances of the same class.
 
@@ -130,7 +130,7 @@ class ModelLine(Traceable):
             # Find anything that matches /path/model_folder/model*
             exact_filename = glob.glob(f'{full_path}*')
 
-            assert len(exact_filename) > 0, 'Model file was\'nt found.\n '
+            assert len(exact_filename) > 0, 'Model file wasn\'t found.\n '
             'It may be that Model didn\'t save itself when save() was called,'
             'or the name of the file didn\'t match "model*"'
 
@@ -153,7 +153,7 @@ class ModelLine(Traceable):
     def __repr__(self) -> str:
         return f'ModelLine of {len(self)} models of {self._model_cls}'
 
-    def get_meta(self) -> Meta:
+    def get_meta(self) -> PipeMeta:
         meta = super().get_meta()
         meta[0].update({
             'root': self.root,
